Documentation
¶
Index ¶
- func AddUserToChannel(t *testing.T, client *model.Client4, channelID, userID string)
- func AddUserToTeam(t *testing.T, client *model.Client4, teamID, userID string)
- func CreateTestChannel(t *testing.T, client *model.Client4, teamID, name, displayName string) *model.Channel
- func CreateTestMCPSession(t *testing.T, mcpServer *mcp.Server) *mcp.ClientSession
- func CreateTestPost(t *testing.T, client *model.Client4, channelID, message string) *model.Post
- func CreateTestTeam(t *testing.T, client *model.Client4, name, displayName string) *model.Team
- func CreateTestUser(t *testing.T, client *model.Client4, username, email, password string) *model.User
- func ExecuteMCPTool(t *testing.T, mcpServer *mcp.Server, toolName string, ...) (*mcp.CallToolResult, error)
- type TestData
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddUserToChannel ¶
AddUserToChannel adds a user to a channel
func AddUserToTeam ¶
AddUserToTeam adds a user to a team
func CreateTestChannel ¶
func CreateTestChannel(t *testing.T, client *model.Client4, teamID, name, displayName string) *model.Channel
CreateTestChannel creates a test channel
func CreateTestMCPSession ¶
CreateTestMCPSession creates an in-memory MCP client session connected to the server This enables testing tools through the full MCP protocol stack without external transports
func CreateTestPost ¶
CreateTestPost creates a test post
func CreateTestTeam ¶
CreateTestTeam creates a test team
func CreateTestUser ¶
func CreateTestUser(t *testing.T, client *model.Client4, username, email, password string) *model.User
CreateTestUser creates a test user
func ExecuteMCPTool ¶
func ExecuteMCPTool(t *testing.T, mcpServer *mcp.Server, toolName string, args map[string]interface{}) (*mcp.CallToolResult, error)
ExecuteMCPTool calls an MCP tool through a test client session This provides true integration testing by using the actual MCP protocol with in-memory transport
Types ¶
Click to show internal directories.
Click to hide internal directories.